@@ -93,7 +93,9 @@ cue_format <- function(cue, target, meta, record) {
   }
   old <- record$format
   new <- target$settings$format
-  !identical(old, new)
+  up_to_date <- identical(old, new) ||
+    (identical(new, "auto") && (old %in% c("file", "qs")))
+  !up_to_date
 }
 
 cue_repository <- function(cue, target, meta, record) {
@@ -124,8 +126,7 @@ cue_file <- function(cue, target, meta, record) {
     hash = record$data,
     time = record$time,
     size = record$size,
-    bytes = record$bytes,
-    trust_timestamps = file_current$trust_timestamps
+    bytes = record$bytes
   )
   on.exit(target$store$file <- file_current)
   target$store$file <- file_recorded
