@@ -1,8 +1,3 @@
-#' @export
-store_set_timestamp_trust.tar_external <- function(store) {
-  store$file$trust_timestamps <- FALSE
-}
-
 #' @export
 store_row_path.tar_external <- function(store) {
   store$file$path
