@@ -97,6 +97,7 @@ future_class <- R6::R6Class(
       self$worker_list <- memory_init()
     },
     run_worker = function(target) {
+      builder_marshal_subpipeline(target)
       if (self$garbage_collection) {
         gc()
       }
@@ -137,7 +138,7 @@ future_class <- R6::R6Class(
         label = target_get_name(target),
         resources = resources,
         lazy = FALSE,
-        seed = 0L
+        seed = FALSE
       )
       future <- do.call(what = future::future, args = args)
       memory_set_object(
