@@ -1,17 +1,29 @@
 resources_aws_init <- function(
   bucket = NULL,
-  prefix = tar_path_objects_dir_cloud(),
+  prefix = path_objects_dir_cloud(),
   region = NULL,
-  part_size = 5 * (2 ^ 20),
   endpoint = NULL,
+  s3_force_path_style = NULL,
+  part_size = 5 * (2 ^ 20),
+  page_size = 1000L,
+  max_tries = NULL,
+  seconds_timeout = NULL,
+  close_connection = NULL,
+  verbose = TRUE,
   args = list()
 ) {
   resources_aws_new(
     bucket = bucket,
     prefix = prefix,
     region = region,
-    part_size = part_size,
     endpoint = endpoint,
+    s3_force_path_style = s3_force_path_style,
+    part_size = part_size,
+    page_size = page_size,
+    max_tries = max_tries,
+    seconds_timeout = seconds_timeout,
+    close_connection = close_connection,
+    verbose = verbose,
     args = args
   )
 }
@@ -20,34 +32,59 @@ resources_aws_new <- function(
   bucket = NULL,
   prefix = NULL,
   region = NULL,
-  part_size = NULL,
   endpoint = NULL,
+  s3_force_path_style = NULL,
+  part_size = NULL,
+  page_size = NULL,
+  max_tries = NULL,
+  seconds_timeout = NULL,
+  close_connection = NULL,
+  verbose = TRUE,
   args = NULL
 ) {
   force(bucket)
   force(prefix)
   force(region)
-  force(part_size)
   force(endpoint)
+  force(s3_force_path_style)
+  force(part_size)
+  force(page_size)
+  force(max_tries)
+  force(seconds_timeout)
+  force(close_connection)
+  force(verbose)
   force(args)
   enclass(environment(), c("tar_resources_aws", "tar_resources"))
 }
 
 #' @export
 resources_validate.tar_resources_aws <- function(resources) {
-  tar_assert_scalar(resources$bucket %|||% "bucket")
-  tar_assert_chr(resources$bucket %|||% "bucket")
-  tar_assert_nzchar(resources$bucket %|||% "bucket")
-  tar_assert_scalar(resources$prefix)
-  tar_assert_chr(resources$prefix)
-  tar_assert_nzchar(resources$prefix)
-  tar_assert_scalar(resources$region %|||% "region")
-  tar_assert_chr(resources$region %|||% "region")
-  tar_assert_scalar(resources$part_size %|||% 1e8)
-  tar_assert_dbl(resources$part_size %|||% 1e8)
-  tar_assert_positive(resources$part_size %|||% 1e8)
-  tar_assert_scalar(resources$endpoint %|||% "endpoint")
-  tar_assert_chr(resources$endpoint %|||% "endpoint")
+  for (field in c("bucket", "prefix")) {
+    msg <- paste("invalid AWS S3", field)
+    tar_assert_scalar(resources[[field]], msg = msg)
+    tar_assert_chr(resources[[field]], msg = msg)
+    tar_assert_none_na(resources[[field]], msg = msg)
+    tar_assert_nzchar(resources[[field]], msg = msg)
+  }
+  for (field in c("region", "endpoint")) {
+    msg <- paste("invalid AWS S3", field)
+    tar_assert_scalar(resources[[field]] %|||% "x", msg = msg)
+    tar_assert_chr(resources[[field]] %|||% "x", msg = msg)
+    tar_assert_none_na(resources[[field]] %|||% "x", msg = msg)
+  }
+  for (field in c("part_size", "page_size", "max_tries", "seconds_timeout")) {
+    msg <- paste("invalid AWS S3", field)
+    tar_assert_scalar(resources[[field]] %|||% 1L, msg = msg)
+    tar_assert_dbl(resources[[field]] %|||% 1L, msg = msg)
+    tar_assert_none_na(resources[[field]] %|||% 1L, msg = msg)
+    tar_assert_ge(resources[[field]] %|||% 1L, 0L, msg = msg)
+  }
+  for (field in c("close_connection", "s3_force_path_style", "verbose")) {
+    msg <- paste("invalid AWS S3", field)
+    tar_assert_scalar(resources[[field]] %|||% TRUE, msg = msg)
+    tar_assert_lgl(resources[[field]] %|||% TRUE, msg = msg)
+    tar_assert_none_na(resources[[field]] %|||% TRUE, msg = msg)
+  }
   resources_aws_validate_args(resources$args)
 }
 
@@ -62,7 +99,7 @@ resources_aws_validate_args <- function(args) {
     setdiff(names(formals(tar_resources_aws)), "..."),
     "bucket", "Bucket", "key", "Key",
     "prefix", "region", "part_size", "endpoint",
-    "version", "VersionId", "body", "Body",
+    "VersionId", "body", "Body",
     "metadata", "Metadata", "UploadId", "MultipartUpload",
     "PartNumber"
   )
