@@ -1,18 +1,16 @@
 #' @export
-store_new.file <- function(format, file = NULL, resources = NULL) {
-  store_file_new(file, resources)
-}
-
-store_file_new <- function(file = NULL, resources = NULL) {
-  force(file)
-  force(resources)
-  enclass(environment(), c("tar_store_file", "tar_external", "tar_store"))
+store_class_format.file <- function(format) {
+  c("tar_store_file", "tar_external", "tar_store")
 }
 
 #' @export
 store_assert_format_setting.file <- function(format) {
 }
 
+#' @export
+store_assert_format_setting.file_fast <- function(format) {
+}
+
 #' @export
 store_read_path.tar_store_file <- function(store, path) {
   path[!is.na(path)]
