@@ -78,15 +78,3 @@ tar_path <- function(
   }
   out
 }
-
-tar_path_running <- function(default, path_store) {
-  if_any(
-    tar_runtime$exists_target(),
-    store_tar_path(
-      tar_runtime$get_target()$store,
-      tar_runtime$get_target(),
-      tar_runtime$get_store()
-    ),
-    as.character(default)
-  )
-}
