@@ -19,8 +19,8 @@
 #' }
 tar_path_store <- function() {
   if_any(
-    tar_runtime$exists_store(),
-    tar_runtime$get_store(),
+    !is.null(tar_runtime$store),
+    tar_runtime$store,
     tar_config_get("store")
   )
 }
