@@ -43,32 +43,6 @@ omit_rownames <- function(x) {
   x
 }
 
-#' @title Generate a random name
-#' @description Uses the lists of adjectives and animals from
-#'   <https://github.com/a-type/adjective-adjective-animal>.
-#'   by Grant Forrest under the MIT license.
-#' @details Not a user-side function. Do not invoke directly.
-#' @export
-#' @keywords internal
-#' @return Character of length 1 with a random name.
-#' @examples
-#' tar_random_name()
-tar_random_name <- function() {
-  path_adjectives <- system.file(
-    file.path("names", "adjectives.rds"),
-    package = "targets",
-    mustWork = TRUE
-  )
-  path_animals <- system.file(
-    file.path("names", "animals.rds"),
-    package = "targets",
-    mustWork = TRUE
-  )
-  adjective <- sample(x = readRDS(path_adjectives), size = 1)
-  animal <- sample(x = readRDS(path_animals), size = 1)
-  sprintf("%s_%s", adjective, animal)
-}
-
 set_names <- function(x, names) {
   names(x) <- names
   x
