@@ -3,12 +3,12 @@
 # Use tar_script() to create _targets.R and tar_edit()
 # to open it again for editing.
 # Then, run tar_make() to run the pipeline
-# and tar_read(summary) to view the results.
+# and tar_read(data_summary) to view the results.
 
 # Define custom functions and other global objects.
 # This is where you write source(\"R/functions.R\")
 # if you keep your functions in external scripts.
-summ <- function(dataset) {
+summarize_data <- function(dataset) {
   colMeans(dataset)
 }
 
@@ -18,5 +18,5 @@ summ <- function(dataset) {
 # End this file with a list of target objects.
 list(
   tar_target(data, data.frame(x = sample.int(100), y = sample.int(100))),
-  tar_target(summary, summ(data)) # Call your custom functions as needed.
+  tar_target(data_summary, summarize_data(data)) # Call your custom functions.
 )
