@@ -556,7 +556,39 @@ tar_test("convert dep loading errors into runtime errors", {
   expect_true(tar_read(x3))
 })
 
-tar_test("error = \"null\"", {
+tar_test("error = \"null\" without branching", {
+  skip_cran()
+  tar_script({
+    library(targets)
+    f <- function(x) {
+      stopifnot(x < 1.5)
+      x
+    }
+    list(
+      tar_target(x, 2),
+      tar_target(y, f(x), error = "null"),
+      tar_target(z, y)
+    )
+  })
+  tar_make(callr_function = NULL)
+  expect_equal(tar_progress(x)$progress, "completed")
+  expect_equal(tar_progress(y)$progress, "errored")
+  expect_equal(tar_progress(z)$progress, "completed")
+  expect_equal(tar_read(x), 2L)
+  expect_null(unname(tar_read(y)))
+  expect_null(unname(tar_read(z)))
+  expect_equal(
+    sort(tar_objects()),
+    sort(c("x", "z"))
+  )
+  expect_equal(
+    list.files(path_objects_dir(path_store_default())),
+    sort(c("x", "z"))
+  )
+  expect_null(tar_read(y))
+})
+
+tar_test("error = \"null\" with branching", {
   skip_cran()
   tar_script({
     library(targets)
@@ -600,3 +632,77 @@ tar_test("error = \"null\"", {
   value <- progress$progress[progress$name == branches[2]]
   expect_equal(value, "errored")
 })
+
+tar_test("error = \"trim\" on a stem", {
+  skip_cran()
+  tar_script({
+    tar_option_set(error = "trim")
+    list(
+      tar_target(index, seq_len(2L)),
+      tar_target(a, stop(paste(as.character(index), collapse = ""))),
+      tar_target(b, a),
+      tar_target(b2, b, pattern = map(b)),
+      tar_target(c, index),
+      tar_target(c2, c),
+      tar_target(d, index,  pattern = map(index)),
+      tar_target(d2, d, pattern = map(d))
+    )
+  })
+  tar_make(callr_function = NULL)
+  names <- c(
+    "a", "c", "c2",
+    "d", tar_meta(d)$children[[1L]], "d2",
+    tar_meta(d2)$children[[1L]], "index"
+  )
+  progress <- tar_progress()
+  expect_equal(nrow(progress), 10L)
+  expect_false(any(c("b", "b2") %in% progress$name))
+  progress <- tar_progress(names = tidyselect::any_of(names))
+  expect_equal(progress$name, names)
+  expect_equal(progress$progress, c("errored", rep("completed", 9L)))
+  tar_make(callr_function = NULL)
+  progress <- tar_progress()
+  expect_equal(nrow(progress), 10L)
+  expect_false(any(c("b", "b2") %in% progress$name))
+  progress <- tar_progress(names = tidyselect::any_of(names))
+  expect_equal(progress$name, names)
+  expect_equal(progress$progress, c("errored", rep("skipped", 9L)))
+})
+
+tar_test("error = \"trim\" on a dynamic branch", {
+  skip_cran()
+  tar_script({
+    tar_option_set(error = "trim")
+    list(
+      tar_target(index, seq_len(2L)),
+      tar_target(a, if (index < 2L) stop(), pattern = map(index)),
+      tar_target(b, a, pattern = map(a)),
+      tar_target(b2, b),
+      tar_target(c, index),
+      tar_target(c2, c),
+      tar_target(d, index,  pattern = map(index)),
+      tar_target(d2, d, pattern = map(d))
+    )
+  })
+  tar_make(callr_function = NULL)
+  names <- c(
+    "c", "c2",
+    "d", tar_meta(d)$children[[1L]], "d2",
+    tar_meta(d2)$children[[1L]], "index"
+  )
+  progress <- tar_progress()
+  expect_equal(nrow(progress), 11L)
+  expect_false(any(c("b", "b2") %in% progress$name))
+  progress <- tar_progress(names = tidyselect::starts_with("a"))
+  expect_equal(unique(progress$progress), "errored")
+  progress <- tar_progress(names = tidyselect::any_of(names))
+  expect_equal(unique(progress$progress), "completed")
+  tar_make(callr_function = NULL)
+  progress <- tar_progress()
+  expect_equal(nrow(progress), 11L)
+  expect_false(any(c("b", "b2") %in% progress$name))
+  progress <- tar_progress(names = tidyselect::starts_with("a"))
+  expect_equal(unique(progress$progress), "errored")
+  progress <- tar_progress(names = tidyselect::any_of(names))
+  expect_equal(unique(progress$progress), "skipped")
+})
