@@ -56,9 +56,9 @@ tar_test("memory_del_objects()", {
   expect_equal(sort(out$names), sort(c("a", "b", "c")))
   expect_equal(out$count, 3L)
   memory_del_objects(out, c("a", "c"))
-  expect_equal(out$envir$a, NULL)
+  expect_null(out$envir$a)
   expect_equal(out$envir$b, "456")
-  expect_equal(out$envir$c, NULL)
+  expect_null(out$envir$c)
   expect_equal(out$names, "b")
   expect_equal(out$count, 1L)
 })
