@@ -28,7 +28,6 @@ tar_test("torch format with in-memory serialization", {
 
 tar_test("torch in-memory serialization of deps", {
   skip_cran()
-  skip_on_os("mac")
   skip_on_os("solaris")
   skip_on_os("windows")
   require_clustermq()
@@ -50,7 +49,7 @@ tar_test("torch in-memory serialization of deps", {
   )
   tar_load(tensor)
   expect_true(inherits(tensor, "torch_tensor"))
-  expect_equal(length(tensor), 10)
+  expect_length(tensor, 10)
   tar_load(array)
   expect_equal(array, rep(0, 10))
 })
