@@ -16,31 +16,31 @@ tar_test("tar_config_set() inherits", {
 tar_test("tar_config_set() as_job", {
   skip_cran()
   expect_false(file.exists("_targets.yaml"))
-  expect_equal(tar_config_get("as_job"), FALSE)
+  expect_false(tar_config_get("as_job"))
   tar_config_set(as_job = TRUE)
-  expect_equal(tar_config_get("as_job"), TRUE)
+  expect_true(tar_config_get("as_job"))
   expect_true(file.exists("_targets.yaml"))
   expect_true(any(grepl("as_job", readLines("_targets.yaml"))))
   tar_config_set()
-  expect_equal(tar_config_get("as_job"), TRUE)
+  expect_true(tar_config_get("as_job"))
   expect_true(file.exists("_targets.yaml"))
   unlink("_targets.yaml")
-  expect_equal(tar_config_get("as_job"), FALSE)
+  expect_false(tar_config_get("as_job"))
 })
 
 tar_test("tar_config_set() garbage_collection", {
   skip_cran()
   expect_false(file.exists("_targets.yaml"))
-  expect_equal(tar_config_get("garbage_collection"), FALSE)
+  expect_false(tar_config_get("garbage_collection"))
   tar_config_set(garbage_collection = TRUE)
-  expect_equal(tar_config_get("garbage_collection"), TRUE)
+  expect_true(tar_config_get("garbage_collection"))
   expect_true(file.exists("_targets.yaml"))
   expect_true(any(grepl("garbage_collection", readLines("_targets.yaml"))))
   tar_config_set()
-  expect_equal(tar_config_get("garbage_collection"), TRUE)
+  expect_true(tar_config_get("garbage_collection"))
   expect_true(file.exists("_targets.yaml"))
   unlink("_targets.yaml")
-  expect_equal(tar_config_get("garbage_collection"), FALSE)
+  expect_false(tar_config_get("garbage_collection"))
 })
 
 tar_test("tar_config_set() label", {
@@ -129,16 +129,16 @@ tar_test("tar_config_set() reporter_outdated", {
 tar_test("tar_config_set() shortcut", {
   skip_cran()
   expect_false(file.exists("_targets.yaml"))
-  expect_equal(tar_config_get("shortcut"), FALSE)
+  expect_false(tar_config_get("shortcut"))
   tar_config_set(shortcut = TRUE)
-  expect_equal(tar_config_get("shortcut"), TRUE)
+  expect_true(tar_config_get("shortcut"))
   expect_true(file.exists("_targets.yaml"))
   expect_true(any(grepl("shortcut", readLines("_targets.yaml"))))
   tar_config_set()
-  expect_equal(tar_config_get("shortcut"), TRUE)
+  expect_true(tar_config_get("shortcut"))
   expect_true(file.exists("_targets.yaml"))
   unlink("_targets.yaml")
-  expect_equal(tar_config_get("shortcut"), FALSE)
+  expect_false(tar_config_get("shortcut"))
 })
 
 tar_test("tar_config_set() with script", {
@@ -273,16 +273,16 @@ tar_test("tar_config_set() with store and different yaml file", {
 tar_test("tar_config_set() use_crew", {
   skip_cran()
   expect_false(file.exists("_targets.yaml"))
-  expect_equal(tar_config_get("use_crew"), TRUE)
+  expect_true(tar_config_get("use_crew"))
   tar_config_set(use_crew = FALSE)
-  expect_equal(tar_config_get("use_crew"), FALSE)
+  expect_false(tar_config_get("use_crew"))
   expect_true(file.exists("_targets.yaml"))
   expect_true(any(grepl("use_crew", readLines("_targets.yaml"))))
   tar_config_set()
-  expect_equal(tar_config_get("use_crew"), FALSE)
+  expect_false(tar_config_get("use_crew"))
   expect_true(file.exists("_targets.yaml"))
   unlink("_targets.yaml")
-  expect_equal(tar_config_get("use_crew"), TRUE)
+  expect_true(tar_config_get("use_crew"))
 })
 
 tar_test("tar_config_set() workers", {
