@@ -114,7 +114,7 @@ tar_test("custom script and store args", {
   expect_true(file.exists("example/store"))
   expect_true(file.exists("example/store/meta/meta"))
   expect_true(file.exists("example/store/objects/x"))
-  expect_equal(readRDS("example/store/objects/x"), TRUE)
+  expect_true(readRDS("example/store/objects/x"))
   tar_config_set(script = "x")
   expect_equal(tar_config_get("script"), "x")
   expect_true(file.exists("_targets.yaml"))
@@ -143,7 +143,7 @@ tar_test("custom script and store args with callr function", {
   expect_true(file.exists("example/store"))
   expect_true(file.exists("example/store/meta/meta"))
   expect_true(file.exists("example/store/objects/x"))
-  expect_equal(readRDS("example/store/objects/x"), TRUE)
+  expect_true(readRDS("example/store/objects/x"))
   tar_config_set(script = "x")
   expect_equal(tar_config_get("script"), "x")
   expect_true(file.exists("_targets.yaml"))
@@ -175,5 +175,5 @@ tar_test("bootstrap builder for shortcut", {
   progress <- tar_progress()
   expect_equal(nrow(progress), 1L)
   expect_equal(progress$name, "z")
-  expect_equal(progress$progress, "built")
+  expect_equal(progress$progress, "completed")
 })
