@@ -13,11 +13,11 @@ tar_test("deprecated option argument", {
 })
 
 tar_test("tidy_eval", {
-  expect_equal(tar_option_get("tidy_eval"), TRUE)
+  expect_true(tar_option_get("tidy_eval"))
   tar_option_set(tidy_eval = FALSE)
-  expect_equal(tar_option_get("tidy_eval"), FALSE)
+  expect_false(tar_option_get("tidy_eval"))
   tar_option_reset()
-  expect_equal(tar_option_get("tidy_eval"), TRUE)
+  expect_true(tar_option_get("tidy_eval"))
   expect_error(
     tar_option_set(tidy_eval = "bad"),
     class = "tar_condition_validate"
@@ -45,11 +45,11 @@ tar_test("imports", {
 })
 
 tar_test("library", {
-  expect_equal(tar_option_get("library"), NULL)
+  expect_null(tar_option_get("library"))
   tar_option_set(library = "x")
   expect_equal(tar_option_get("library"), "x")
   tar_option_reset()
-  expect_equal(tar_option_get("library"), NULL)
+  expect_null(tar_option_get("library"))
   expect_error(tar_option_set(library = 123), class = "tar_condition_validate")
 })
 
@@ -98,6 +98,12 @@ tar_test("repository_meta", {
     tar_option_set(repository_meta = 123),
     class = "tar_condition_validate"
   )
+  expect_error(
+    tar_option_set(repository_meta = tar_repository_cas_local()),
+    class = "tar_condition_validate"
+  )
+  tar_option_set(repository = tar_repository_cas_local())
+  expect_equal(tar_option_get("repository_meta"), "local")
 })
 
 tar_test("repository_meta", {
@@ -159,11 +165,11 @@ tar_test("memory", {
 })
 
 tar_test("garbage_collection", {
-  expect_equal(tar_option_get("garbage_collection"), FALSE)
+  expect_false(tar_option_get("garbage_collection"))
   tar_option_set(garbage_collection = TRUE)
-  expect_equal(tar_option_get("garbage_collection"), TRUE)
+  expect_true(tar_option_get("garbage_collection"))
   tar_option_reset()
-  expect_equal(tar_option_get("garbage_collection"), FALSE)
+  expect_false(tar_option_get("garbage_collection"))
   expect_error(
     tar_option_set(garbage_collection = 0),
     class = "tar_condition_validate"
@@ -323,11 +329,11 @@ tar_test("workspaces", {
 })
 
 tar_test("workspace_on_error", {
-  expect_equal(tar_option_get("workspace_on_error"), FALSE)
-  tar_option_set(workspace_on_error = TRUE)
-  expect_equal(tar_option_get("workspace_on_error"), TRUE)
+  expect_true(tar_option_get("workspace_on_error"))
+  tar_option_set(workspace_on_error = FALSE)
+  expect_false(tar_option_get("workspace_on_error"))
   tar_option_reset()
-  expect_equal(tar_option_get("workspace_on_error"), FALSE)
+  expect_true(tar_option_get("workspace_on_error"))
   expect_error(
     tar_option_set(workspace_on_error = 123),
     class = "tar_condition_validate"
@@ -365,14 +371,26 @@ tar_test("controller", {
   )
 })
 
-tar_test("trust_object_timestamps", {
-  expect_equal(tar_option_get("trust_object_timestamps"), TRUE)
-  tar_option_set(trust_object_timestamps = FALSE)
-  expect_equal(tar_option_get("trust_object_timestamps"), FALSE)
+tar_test("trust_timestamps", {
+  expect_null(tar_option_get("trust_timestamps"))
+  tar_option_set(trust_timestamps = FALSE)
+  expect_false(tar_option_get("trust_timestamps"))
   tar_option_reset()
-  expect_equal(tar_option_get("trust_object_timestamps"), TRUE)
+  expect_null(tar_option_get("trust_timestamps"))
   expect_error(
-    tar_option_set(trust_object_timestamps = 0),
+    tar_option_set(trust_timestamps = 0),
     class = "tar_condition_validate"
   )
 })
+
+tar_test("deprecate trust_object_timestamps", {
+  expect_warning(
+    out <- tar_option_get("trust_object_timestamps"),
+    class = "tar_condition_deprecate"
+  )
+  expect_null(out)
+  expect_warning(
+    tar_option_set(trust_object_timestamps = FALSE),
+    class = "tar_condition_deprecate"
+  )
+})
